/*==================================================================================================
*   Project              : RTD AUTOSAR 4.4
*   Platform             : CORTEXM
*   Peripheral           : FTFC_FLS_IP IPV_QSPI
*   Dependencies         : none
*
*   Autosar Version      : 4.4.0
*   Autosar Revision     : ASR_REL_4_4_REV_0000
*   Autosar Conf.Variant :
*   SW Version           : 1.0.0
*   Build Version        : S32K1_RTD_1_0_0_HF01_D2109_ASR_REL_4_4_REV_0000_20210907
*
*   (c) Copyright 2020-2021 NXP Semiconductors
*   All Rights Reserved.
*
*   NXP Confidential. This software is owned or controlled by NXP and may only be
*   used strictly in accordance with the applicable license terms. By expressly
*   accepting such terms or by downloading, installing, activating and/or otherwise
*   using the software, you are agreeing that you have read, and that you agree to
*   comply with and are bound by, such license terms. If you do not agree to be
*   bound by the applicable license terms, then you may not retain, install,
*   activate or otherwise use the software.
==================================================================================================*/

/**
*   @file Fls_VS_0_PBcfg.c
*
*   @addtogroup FLS
*   @{
*/

/* implements Fls_PBcfg.c_Artifact */

#ifdef __cplusplus
extern "C"{
#endif


/*==================================================================================================
*                                        INCLUDE FILES
* 1) system and project includes
* 2) needed interfaces from external units
* 3) internal and external interfaces from this unit
==================================================================================================*/
#include "Fls.h"
#include "Qspi_Ip_Features.h"
#include "Qspi_Ip_Cfg.h"

/*==================================================================================================
*                              SOURCE FILE VERSION INFORMATION
==================================================================================================*/
#define FLS_VENDOR_ID_CFG_C                      43
#define FLS_AR_RELEASE_MAJOR_VERSION_CFG_C       4
#define FLS_AR_RELEASE_MINOR_VERSION_CFG_C       4
#define FLS_AR_RELEASE_REVISION_VERSION_CFG_C    0
#define FLS_SW_MAJOR_VERSION_CFG_C               1
#define FLS_SW_MINOR_VERSION_CFG_C               0
#define FLS_SW_PATCH_VERSION_CFG_C               0

/*==================================================================================================
*                                     FILE VERSION CHECKS
==================================================================================================*/
/* Check if current file and Fls header file are of the same vendor */
#if (FLS_VENDOR_ID_CFG_C != FLS_VENDOR_ID)
    #error "Fls_PBcfg.c and Fls.h have different vendor ids"
#endif
/* Check if current file and Fls header file are of the same Autosar version */
#if ((FLS_AR_RELEASE_MAJOR_VERSION_CFG_C    != FLS_AR_RELEASE_MAJOR_VERSION) || \
     (FLS_AR_RELEASE_MINOR_VERSION_CFG_C    != FLS_AR_RELEASE_MINOR_VERSION) || \
     (FLS_AR_RELEASE_REVISION_VERSION_CFG_C != FLS_AR_RELEASE_REVISION_VERSION) \
    )
    #error "AutoSar Version Numbers of Fls_PBcfg.c and Fls.h are different"
#endif
/* Check if current file and Fls header file are of the same Software version */
#if ((FLS_SW_MAJOR_VERSION_CFG_C != FLS_SW_MAJOR_VERSION) || \
     (FLS_SW_MINOR_VERSION_CFG_C != FLS_SW_MINOR_VERSION) || \
     (FLS_SW_PATCH_VERSION_CFG_C != FLS_SW_PATCH_VERSION) \
    )
    #error "Software Version Numbers of Fls_PBcfg.c and Fls.h are different"
#endif

/* Check if current file and Qspi_Ip_Features header file are of the same vendor */
#if (FLS_VENDOR_ID_CFG_C != QSPI_IP_FEATURES_VENDOR_ID_CFG)
    #error "Fls_PBcfg.c and Qspi_Ip_Features.h have different vendor ids"
#endif
/* Check if current file and Qspi_Ip_Features header file are of the same Autosar version */
#if ((FLS_AR_RELEASE_MAJOR_VERSION_CFG_C    != QSPI_IP_FEATURES_AR_RELEASE_MAJOR_VERSION_CFG) || \
     (FLS_AR_RELEASE_MINOR_VERSION_CFG_C    != QSPI_IP_FEATURES_AR_RELEASE_MINOR_VERSION_CFG) || \
     (FLS_AR_RELEASE_REVISION_VERSION_CFG_C != QSPI_IP_FEATURES_AR_RELEASE_REVISION_VERSION_CFG) \
    )
    #error "AutoSar Version Numbers of Fls_PBcfg.c and Qspi_Ip_Features.h are different"
#endif
/* Check if current file and Qspi_Ip_Features header file are of the same Software version */
#if ((FLS_SW_MAJOR_VERSION_CFG_C != QSPI_IP_FEATURES_SW_MAJOR_VERSION_CFG) || \
     (FLS_SW_MINOR_VERSION_CFG_C != QSPI_IP_FEATURES_SW_MINOR_VERSION_CFG) || \
     (FLS_SW_PATCH_VERSION_CFG_C != QSPI_IP_FEATURES_SW_PATCH_VERSION_CFG) \
    )
    #error "Software Version Numbers of Fls_PBcfg.c and Qspi_Ip_Features.h are different"
#endif

/* Check if current file and Qspi_Ip_Cfg header file are of the same vendor */
#if (FLS_VENDOR_ID_CFG_C != QSPI_IP_VENDOR_ID_CFG)
    #error "Fls_PBcfg.c and Qspi_Ip_Cfg.h have different vendor ids"
#endif
/* Check if current file and Qspi_Ip_Cfg header file are of the same Autosar version */
#if ((FLS_AR_RELEASE_MAJOR_VERSION_CFG_C    != QSPI_IP_AR_RELEASE_MAJOR_VERSION_CFG) || \
     (FLS_AR_RELEASE_MINOR_VERSION_CFG_C    != QSPI_IP_AR_RELEASE_MINOR_VERSION_CFG) || \
     (FLS_AR_RELEASE_REVISION_VERSION_CFG_C != QSPI_IP_AR_RELEASE_REVISION_VERSION_CFG) \
    )
    #error "AutoSar Version Numbers of Fls_PBcfg.c and Qspi_Ip_Cfg.h are different"
#endif
/* Check if current file and Qspi_Ip_Cfg header file are of the same Software version */
#if ((FLS_SW_MAJOR_VERSION_CFG_C != QSPI_IP_SW_MAJOR_VERSION_CFG) || \
     (FLS_SW_MINOR_VERSION_CFG_C != QSPI_IP_SW_MINOR_VERSION_CFG) || \
     (FLS_SW_PATCH_VERSION_CFG_C != QSPI_IP_SW_PATCH_VERSION_CFG) \
    )
    #error "Software Version Numbers of Fls_PBcfg.c and Qspi_Ip_Cfg.h are different"
#endif

/*==================================================================================================
                                     FUNCTION PROTOTYPES
==================================================================================================*/

/*==================================================================================================
                                           CONSTANTS
==================================================================================================*/
#define FLS_START_SEC_CODE
#include "Fls_MemMap.h"

/* Declaration of Fls Access Code Pointer (_ERASE_FUNC_ADDRESS_)*/
extern void _ERASE_FUNC_ADDRESS_(void);

/* Declaration of Fls Access Code Pointer (_WRITE_FUNC_ADDRESS_)*/
extern void _WRITE_FUNC_ADDRESS_(void);

#define FLS_STOP_SEC_CODE
#include "Fls_MemMap.h"
#define FLS_START_SEC_CONFIG_DATA_8
#include "Fls_MemMap.h"

/* aFlsSectorFlags */
static const uint8 FlsConfigSet_VS_0_aFlsSectorFlags[128U] =
{
    0U,  /* FlsSector_0 */
    0U,  /* FlsSector_1 */
    0U,  /* FlsSector_2 */
    0U,  /* FlsSector_3 */
    0U,  /* FlsSector_4 */
    0U,  /* FlsSector_5 */
    0U,  /* FlsSector_6 */
    0U,  /* FlsSector_7 */
    0U,  /* FlsSector_8 */
    0U,  /* FlsSector_9 */
    0U,  /* FlsSector_10 */
    0U,  /* FlsSector_11 */
    0U,  /* FlsSector_12 */
    0U,  /* FlsSector_13 */
    0U,  /* FlsSector_14 */
    0U,  /* FlsSector_15 */
    0U,  /* FlsSector_16 */
    0U,  /* FlsSector_17 */
    0U,  /* FlsSector_18 */
    0U,  /* FlsSector_19 */
    0U,  /* FlsSector_20 */
    0U,  /* FlsSector_21 */
    0U,  /* FlsSector_22 */
    0U,  /* FlsSector_23 */
    0U,  /* FlsSector_24 */
    0U,  /* FlsSector_25 */
    0U,  /* FlsSector_26 */
    0U,  /* FlsSector_27 */
    0U,  /* FlsSector_28 */
    0U,  /* FlsSector_29 */
    0U,  /* FlsSector_30 */
    0U,  /* FlsSector_31 */
    0U,  /* FlsSector_32 */
    0U,  /* FlsSector_33 */
    0U,  /* FlsSector_34 */
    0U,  /* FlsSector_35 */
    0U,  /* FlsSector_36 */
    0U,  /* FlsSector_37 */
    0U,  /* FlsSector_38 */
    0U,  /* FlsSector_39 */
    0U,  /* FlsSector_40 */
    0U,  /* FlsSector_41 */
    0U,  /* FlsSector_42 */
    0U,  /* FlsSector_43 */
    0U,  /* FlsSector_44 */
    0U,  /* FlsSector_45 */
    0U,  /* FlsSector_46 */
    0U,  /* FlsSector_47 */
    0U,  /* FlsSector_48 */
    0U,  /* FlsSector_49 */
    0U,  /* FlsSector_50 */
    0U,  /* FlsSector_51 */
    0U,  /* FlsSector_52 */
    0U,  /* FlsSector_53 */
    0U,  /* FlsSector_54 */
    0U,  /* FlsSector_55 */
    0U,  /* FlsSector_56 */
    0U,  /* FlsSector_57 */
    0U,  /* FlsSector_58 */
    0U,  /* FlsSector_59 */
    0U,  /* FlsSector_60 */
    0U,  /* FlsSector_61 */
    0U,  /* FlsSector_62 */
    0U,  /* FlsSector_63 */
    0U,  /* FlsSector_64 */
    0U,  /* FlsSector_65 */
    0U,  /* FlsSector_66 */
    0U,  /* FlsSector_67 */
    0U,  /* FlsSector_68 */
    0U,  /* FlsSector_69 */
    0U,  /* FlsSector_70 */
    0U,  /* FlsSector_71 */
    0U,  /* FlsSector_72 */
    0U,  /* FlsSector_73 */
    0U,  /* FlsSector_74 */
    0U,  /* FlsSector_75 */
    0U,  /* FlsSector_76 */
    0U,  /* FlsSector_77 */
    0U,  /* FlsSector_78 */
    0U,  /* FlsSector_79 */
    0U,  /* FlsSector_80 */
    0U,  /* FlsSector_81 */
    0U,  /* FlsSector_82 */
    0U,  /* FlsSector_83 */
    0U,  /* FlsSector_84 */
    0U,  /* FlsSector_85 */
    0U,  /* FlsSector_86 */
    0U,  /* FlsSector_87 */
    0U,  /* FlsSector_88 */
    0U,  /* FlsSector_89 */
    0U,  /* FlsSector_90 */
    0U,  /* FlsSector_91 */
    0U,  /* FlsSector_92 */
    0U,  /* FlsSector_93 */
    0U,  /* FlsSector_94 */
    0U,  /* FlsSector_95 */
    0U,  /* FlsSector_96 */
    0U,  /* FlsSector_97 */
    0U,  /* FlsSector_98 */
    0U,  /* FlsSector_99 */
    0U,  /* FlsSector_100 */
    0U,  /* FlsSector_101 */
    0U,  /* FlsSector_102 */
    0U,  /* FlsSector_103 */
    0U,  /* FlsSector_104 */
    0U,  /* FlsSector_105 */
    0U,  /* FlsSector_106 */
    0U,  /* FlsSector_107 */
    0U,  /* FlsSector_108 */
    0U,  /* FlsSector_109 */
    0U,  /* FlsSector_110 */
    0U,  /* FlsSector_111 */
    0U,  /* FlsSector_112 */
    0U,  /* FlsSector_113 */
    0U,  /* FlsSector_114 */
    0U,  /* FlsSector_115 */
    0U,  /* FlsSector_116 */
    0U,  /* FlsSector_117 */
    0U,  /* FlsSector_118 */
    0U,  /* FlsSector_119 */
    0U,  /* FlsSector_120 */
    0U,  /* FlsSector_121 */
    0U,  /* FlsSector_122 */
    0U,  /* FlsSector_123 */
    0U,  /* FlsSector_124 */
    0U,  /* FlsSector_125 */
    0U,  /* FlsSector_126 */
    0U   /* FlsSector_127 */
};

#define FLS_STOP_SEC_CONFIG_DATA_8
#include "Fls_MemMap.h"



#define FLS_START_SEC_CONFIG_DATA_UNSPECIFIED
#include "Fls_MemMap.h"

/* aFlsSectorEndAddr */
static const Fls_AddressType FlsConfigSet_VS_0_aFlsSectorEndAddr[128U] =
{
    (Fls_AddressType)4095U,  /* FlsSector_0 */
    (Fls_AddressType)8191U,  /* FlsSector_1 */
    (Fls_AddressType)12287U,  /* FlsSector_2 */
    (Fls_AddressType)16383U,  /* FlsSector_3 */
    (Fls_AddressType)20479U,  /* FlsSector_4 */
    (Fls_AddressType)24575U,  /* FlsSector_5 */
    (Fls_AddressType)28671U,  /* FlsSector_6 */
    (Fls_AddressType)32767U,  /* FlsSector_7 */
    (Fls_AddressType)36863U,  /* FlsSector_8 */
    (Fls_AddressType)40959U,  /* FlsSector_9 */
    (Fls_AddressType)45055U,  /* FlsSector_10 */
    (Fls_AddressType)49151U,  /* FlsSector_11 */
    (Fls_AddressType)53247U,  /* FlsSector_12 */
    (Fls_AddressType)57343U,  /* FlsSector_13 */
    (Fls_AddressType)61439U,  /* FlsSector_14 */
    (Fls_AddressType)65535U,  /* FlsSector_15 */
    (Fls_AddressType)69631U,  /* FlsSector_16 */
    (Fls_AddressType)73727U,  /* FlsSector_17 */
    (Fls_AddressType)77823U,  /* FlsSector_18 */
    (Fls_AddressType)81919U,  /* FlsSector_19 */
    (Fls_AddressType)86015U,  /* FlsSector_20 */
    (Fls_AddressType)90111U,  /* FlsSector_21 */
    (Fls_AddressType)94207U,  /* FlsSector_22 */
    (Fls_AddressType)98303U,  /* FlsSector_23 */
    (Fls_AddressType)102399U,  /* FlsSector_24 */
    (Fls_AddressType)106495U,  /* FlsSector_25 */
    (Fls_AddressType)110591U,  /* FlsSector_26 */
    (Fls_AddressType)114687U,  /* FlsSector_27 */
    (Fls_AddressType)118783U,  /* FlsSector_28 */
    (Fls_AddressType)122879U,  /* FlsSector_29 */
    (Fls_AddressType)126975U,  /* FlsSector_30 */
    (Fls_AddressType)131071U,  /* FlsSector_31 */
    (Fls_AddressType)135167U,  /* FlsSector_32 */
    (Fls_AddressType)139263U,  /* FlsSector_33 */
    (Fls_AddressType)143359U,  /* FlsSector_34 */
    (Fls_AddressType)147455U,  /* FlsSector_35 */
    (Fls_AddressType)151551U,  /* FlsSector_36 */
    (Fls_AddressType)155647U,  /* FlsSector_37 */
    (Fls_AddressType)159743U,  /* FlsSector_38 */
    (Fls_AddressType)163839U,  /* FlsSector_39 */
    (Fls_AddressType)167935U,  /* FlsSector_40 */
    (Fls_AddressType)172031U,  /* FlsSector_41 */
    (Fls_AddressType)176127U,  /* FlsSector_42 */
    (Fls_AddressType)180223U,  /* FlsSector_43 */
    (Fls_AddressType)184319U,  /* FlsSector_44 */
    (Fls_AddressType)188415U,  /* FlsSector_45 */
    (Fls_AddressType)192511U,  /* FlsSector_46 */
    (Fls_AddressType)196607U,  /* FlsSector_47 */
    (Fls_AddressType)200703U,  /* FlsSector_48 */
    (Fls_AddressType)204799U,  /* FlsSector_49 */
    (Fls_AddressType)208895U,  /* FlsSector_50 */
    (Fls_AddressType)212991U,  /* FlsSector_51 */
    (Fls_AddressType)217087U,  /* FlsSector_52 */
    (Fls_AddressType)221183U,  /* FlsSector_53 */
    (Fls_AddressType)225279U,  /* FlsSector_54 */
    (Fls_AddressType)229375U,  /* FlsSector_55 */
    (Fls_AddressType)233471U,  /* FlsSector_56 */
    (Fls_AddressType)237567U,  /* FlsSector_57 */
    (Fls_AddressType)241663U,  /* FlsSector_58 */
    (Fls_AddressType)245759U,  /* FlsSector_59 */
    (Fls_AddressType)249855U,  /* FlsSector_60 */
    (Fls_AddressType)253951U,  /* FlsSector_61 */
    (Fls_AddressType)258047U,  /* FlsSector_62 */
    (Fls_AddressType)262143U,  /* FlsSector_63 */
    (Fls_AddressType)266239U,  /* FlsSector_64 */
    (Fls_AddressType)270335U,  /* FlsSector_65 */
    (Fls_AddressType)274431U,  /* FlsSector_66 */
    (Fls_AddressType)278527U,  /* FlsSector_67 */
    (Fls_AddressType)282623U,  /* FlsSector_68 */
    (Fls_AddressType)286719U,  /* FlsSector_69 */
    (Fls_AddressType)290815U,  /* FlsSector_70 */
    (Fls_AddressType)294911U,  /* FlsSector_71 */
    (Fls_AddressType)299007U,  /* FlsSector_72 */
    (Fls_AddressType)303103U,  /* FlsSector_73 */
    (Fls_AddressType)307199U,  /* FlsSector_74 */
    (Fls_AddressType)311295U,  /* FlsSector_75 */
    (Fls_AddressType)315391U,  /* FlsSector_76 */
    (Fls_AddressType)319487U,  /* FlsSector_77 */
    (Fls_AddressType)323583U,  /* FlsSector_78 */
    (Fls_AddressType)327679U,  /* FlsSector_79 */
    (Fls_AddressType)331775U,  /* FlsSector_80 */
    (Fls_AddressType)335871U,  /* FlsSector_81 */
    (Fls_AddressType)339967U,  /* FlsSector_82 */
    (Fls_AddressType)344063U,  /* FlsSector_83 */
    (Fls_AddressType)348159U,  /* FlsSector_84 */
    (Fls_AddressType)352255U,  /* FlsSector_85 */
    (Fls_AddressType)356351U,  /* FlsSector_86 */
    (Fls_AddressType)360447U,  /* FlsSector_87 */
    (Fls_AddressType)364543U,  /* FlsSector_88 */
    (Fls_AddressType)368639U,  /* FlsSector_89 */
    (Fls_AddressType)372735U,  /* FlsSector_90 */
    (Fls_AddressType)376831U,  /* FlsSector_91 */
    (Fls_AddressType)380927U,  /* FlsSector_92 */
    (Fls_AddressType)385023U,  /* FlsSector_93 */
    (Fls_AddressType)389119U,  /* FlsSector_94 */
    (Fls_AddressType)393215U,  /* FlsSector_95 */
    (Fls_AddressType)397311U,  /* FlsSector_96 */
    (Fls_AddressType)401407U,  /* FlsSector_97 */
    (Fls_AddressType)405503U,  /* FlsSector_98 */
    (Fls_AddressType)409599U,  /* FlsSector_99 */
    (Fls_AddressType)413695U,  /* FlsSector_100 */
    (Fls_AddressType)417791U,  /* FlsSector_101 */
    (Fls_AddressType)421887U,  /* FlsSector_102 */
    (Fls_AddressType)425983U,  /* FlsSector_103 */
    (Fls_AddressType)430079U,  /* FlsSector_104 */
    (Fls_AddressType)434175U,  /* FlsSector_105 */
    (Fls_AddressType)438271U,  /* FlsSector_106 */
    (Fls_AddressType)442367U,  /* FlsSector_107 */
    (Fls_AddressType)446463U,  /* FlsSector_108 */
    (Fls_AddressType)450559U,  /* FlsSector_109 */
    (Fls_AddressType)454655U,  /* FlsSector_110 */
    (Fls_AddressType)458751U,  /* FlsSector_111 */
    (Fls_AddressType)462847U,  /* FlsSector_112 */
    (Fls_AddressType)466943U,  /* FlsSector_113 */
    (Fls_AddressType)471039U,  /* FlsSector_114 */
    (Fls_AddressType)475135U,  /* FlsSector_115 */
    (Fls_AddressType)479231U,  /* FlsSector_116 */
    (Fls_AddressType)483327U,  /* FlsSector_117 */
    (Fls_AddressType)487423U,  /* FlsSector_118 */
    (Fls_AddressType)491519U,  /* FlsSector_119 */
    (Fls_AddressType)495615U,  /* FlsSector_120 */
    (Fls_AddressType)499711U,  /* FlsSector_121 */
    (Fls_AddressType)503807U,  /* FlsSector_122 */
    (Fls_AddressType)507903U,  /* FlsSector_123 */
    (Fls_AddressType)511999U,  /* FlsSector_124 */
    (Fls_AddressType)516095U,  /* FlsSector_125 */
    (Fls_AddressType)520191U,  /* FlsSector_126 */
    (Fls_AddressType)524287U   /* FlsSector_127 */
};

/* paSectorSize */
static const Fls_LengthType FlsConfigSet_VS_0_aFlsSectorSize[128U] =
{
    (Fls_LengthType)4096U,  /* FlsSector_0 */
    (Fls_LengthType)4096U,  /* FlsSector_1 */
    (Fls_LengthType)4096U,  /* FlsSector_2 */
    (Fls_LengthType)4096U,  /* FlsSector_3 */
    (Fls_LengthType)4096U,  /* FlsSector_4 */
    (Fls_LengthType)4096U,  /* FlsSector_5 */
    (Fls_LengthType)4096U,  /* FlsSector_6 */
    (Fls_LengthType)4096U,  /* FlsSector_7 */
    (Fls_LengthType)4096U,  /* FlsSector_8 */
    (Fls_LengthType)4096U,  /* FlsSector_9 */
    (Fls_LengthType)4096U,  /* FlsSector_10 */
    (Fls_LengthType)4096U,  /* FlsSector_11 */
    (Fls_LengthType)4096U,  /* FlsSector_12 */
    (Fls_LengthType)4096U,  /* FlsSector_13 */
    (Fls_LengthType)4096U,  /* FlsSector_14 */
    (Fls_LengthType)4096U,  /* FlsSector_15 */
    (Fls_LengthType)4096U,  /* FlsSector_16 */
    (Fls_LengthType)4096U,  /* FlsSector_17 */
    (Fls_LengthType)4096U,  /* FlsSector_18 */
    (Fls_LengthType)4096U,  /* FlsSector_19 */
    (Fls_LengthType)4096U,  /* FlsSector_20 */
    (Fls_LengthType)4096U,  /* FlsSector_21 */
    (Fls_LengthType)4096U,  /* FlsSector_22 */
    (Fls_LengthType)4096U,  /* FlsSector_23 */
    (Fls_LengthType)4096U,  /* FlsSector_24 */
    (Fls_LengthType)4096U,  /* FlsSector_25 */
    (Fls_LengthType)4096U,  /* FlsSector_26 */
    (Fls_LengthType)4096U,  /* FlsSector_27 */
    (Fls_LengthType)4096U,  /* FlsSector_28 */
    (Fls_LengthType)4096U,  /* FlsSector_29 */
    (Fls_LengthType)4096U,  /* FlsSector_30 */
    (Fls_LengthType)4096U,  /* FlsSector_31 */
    (Fls_LengthType)4096U,  /* FlsSector_32 */
    (Fls_LengthType)4096U,  /* FlsSector_33 */
    (Fls_LengthType)4096U,  /* FlsSector_34 */
    (Fls_LengthType)4096U,  /* FlsSector_35 */
    (Fls_LengthType)4096U,  /* FlsSector_36 */
    (Fls_LengthType)4096U,  /* FlsSector_37 */
    (Fls_LengthType)4096U,  /* FlsSector_38 */
    (Fls_LengthType)4096U,  /* FlsSector_39 */
    (Fls_LengthType)4096U,  /* FlsSector_40 */
    (Fls_LengthType)4096U,  /* FlsSector_41 */
    (Fls_LengthType)4096U,  /* FlsSector_42 */
    (Fls_LengthType)4096U,  /* FlsSector_43 */
    (Fls_LengthType)4096U,  /* FlsSector_44 */
    (Fls_LengthType)4096U,  /* FlsSector_45 */
    (Fls_LengthType)4096U,  /* FlsSector_46 */
    (Fls_LengthType)4096U,  /* FlsSector_47 */
    (Fls_LengthType)4096U,  /* FlsSector_48 */
    (Fls_LengthType)4096U,  /* FlsSector_49 */
    (Fls_LengthType)4096U,  /* FlsSector_50 */
    (Fls_LengthType)4096U,  /* FlsSector_51 */
    (Fls_LengthType)4096U,  /* FlsSector_52 */
    (Fls_LengthType)4096U,  /* FlsSector_53 */
    (Fls_LengthType)4096U,  /* FlsSector_54 */
    (Fls_LengthType)4096U,  /* FlsSector_55 */
    (Fls_LengthType)4096U,  /* FlsSector_56 */
    (Fls_LengthType)4096U,  /* FlsSector_57 */
    (Fls_LengthType)4096U,  /* FlsSector_58 */
    (Fls_LengthType)4096U,  /* FlsSector_59 */
    (Fls_LengthType)4096U,  /* FlsSector_60 */
    (Fls_LengthType)4096U,  /* FlsSector_61 */
    (Fls_LengthType)4096U,  /* FlsSector_62 */
    (Fls_LengthType)4096U,  /* FlsSector_63 */
    (Fls_LengthType)4096U,  /* FlsSector_64 */
    (Fls_LengthType)4096U,  /* FlsSector_65 */
    (Fls_LengthType)4096U,  /* FlsSector_66 */
    (Fls_LengthType)4096U,  /* FlsSector_67 */
    (Fls_LengthType)4096U,  /* FlsSector_68 */
    (Fls_LengthType)4096U,  /* FlsSector_69 */
    (Fls_LengthType)4096U,  /* FlsSector_70 */
    (Fls_LengthType)4096U,  /* FlsSector_71 */
    (Fls_LengthType)4096U,  /* FlsSector_72 */
    (Fls_LengthType)4096U,  /* FlsSector_73 */
    (Fls_LengthType)4096U,  /* FlsSector_74 */
    (Fls_LengthType)4096U,  /* FlsSector_75 */
    (Fls_LengthType)4096U,  /* FlsSector_76 */
    (Fls_LengthType)4096U,  /* FlsSector_77 */
    (Fls_LengthType)4096U,  /* FlsSector_78 */
    (Fls_LengthType)4096U,  /* FlsSector_79 */
    (Fls_LengthType)4096U,  /* FlsSector_80 */
    (Fls_LengthType)4096U,  /* FlsSector_81 */
    (Fls_LengthType)4096U,  /* FlsSector_82 */
    (Fls_LengthType)4096U,  /* FlsSector_83 */
    (Fls_LengthType)4096U,  /* FlsSector_84 */
    (Fls_LengthType)4096U,  /* FlsSector_85 */
    (Fls_LengthType)4096U,  /* FlsSector_86 */
    (Fls_LengthType)4096U,  /* FlsSector_87 */
    (Fls_LengthType)4096U,  /* FlsSector_88 */
    (Fls_LengthType)4096U,  /* FlsSector_89 */
    (Fls_LengthType)4096U,  /* FlsSector_90 */
    (Fls_LengthType)4096U,  /* FlsSector_91 */
    (Fls_LengthType)4096U,  /* FlsSector_92 */
    (Fls_LengthType)4096U,  /* FlsSector_93 */
    (Fls_LengthType)4096U,  /* FlsSector_94 */
    (Fls_LengthType)4096U,  /* FlsSector_95 */
    (Fls_LengthType)4096U,  /* FlsSector_96 */
    (Fls_LengthType)4096U,  /* FlsSector_97 */
    (Fls_LengthType)4096U,  /* FlsSector_98 */
    (Fls_LengthType)4096U,  /* FlsSector_99 */
    (Fls_LengthType)4096U,  /* FlsSector_100 */
    (Fls_LengthType)4096U,  /* FlsSector_101 */
    (Fls_LengthType)4096U,  /* FlsSector_102 */
    (Fls_LengthType)4096U,  /* FlsSector_103 */
    (Fls_LengthType)4096U,  /* FlsSector_104 */
    (Fls_LengthType)4096U,  /* FlsSector_105 */
    (Fls_LengthType)4096U,  /* FlsSector_106 */
    (Fls_LengthType)4096U,  /* FlsSector_107 */
    (Fls_LengthType)4096U,  /* FlsSector_108 */
    (Fls_LengthType)4096U,  /* FlsSector_109 */
    (Fls_LengthType)4096U,  /* FlsSector_110 */
    (Fls_LengthType)4096U,  /* FlsSector_111 */
    (Fls_LengthType)4096U,  /* FlsSector_112 */
    (Fls_LengthType)4096U,  /* FlsSector_113 */
    (Fls_LengthType)4096U,  /* FlsSector_114 */
    (Fls_LengthType)4096U,  /* FlsSector_115 */
    (Fls_LengthType)4096U,  /* FlsSector_116 */
    (Fls_LengthType)4096U,  /* FlsSector_117 */
    (Fls_LengthType)4096U,  /* FlsSector_118 */
    (Fls_LengthType)4096U,  /* FlsSector_119 */
    (Fls_LengthType)4096U,  /* FlsSector_120 */
    (Fls_LengthType)4096U,  /* FlsSector_121 */
    (Fls_LengthType)4096U,  /* FlsSector_122 */
    (Fls_LengthType)4096U,  /* FlsSector_123 */
    (Fls_LengthType)4096U,  /* FlsSector_124 */
    (Fls_LengthType)4096U,  /* FlsSector_125 */
    (Fls_LengthType)4096U,  /* FlsSector_126 */
    (Fls_LengthType)4096U   /* FlsSector_127 */
};

/* paSectorPageSize */
static const Fls_LengthType FlsConfigSet_VS_0_aFlsSectorPageSize[128U] =
{
    (Fls_LengthType)8U,  /* FlsSector_0 */
    (Fls_LengthType)8U,  /* FlsSector_1 */
    (Fls_LengthType)8U,  /* FlsSector_2 */
    (Fls_LengthType)8U,  /* FlsSector_3 */
    (Fls_LengthType)8U,  /* FlsSector_4 */
    (Fls_LengthType)8U,  /* FlsSector_5 */
    (Fls_LengthType)8U,  /* FlsSector_6 */
    (Fls_LengthType)8U,  /* FlsSector_7 */
    (Fls_LengthType)8U,  /* FlsSector_8 */
    (Fls_LengthType)8U,  /* FlsSector_9 */
    (Fls_LengthType)8U,  /* FlsSector_10 */
    (Fls_LengthType)8U,  /* FlsSector_11 */
    (Fls_LengthType)8U,  /* FlsSector_12 */
    (Fls_LengthType)8U,  /* FlsSector_13 */
    (Fls_LengthType)8U,  /* FlsSector_14 */
    (Fls_LengthType)8U,  /* FlsSector_15 */
    (Fls_LengthType)8U,  /* FlsSector_16 */
    (Fls_LengthType)8U,  /* FlsSector_17 */
    (Fls_LengthType)8U,  /* FlsSector_18 */
    (Fls_LengthType)8U,  /* FlsSector_19 */
    (Fls_LengthType)8U,  /* FlsSector_20 */
    (Fls_LengthType)8U,  /* FlsSector_21 */
    (Fls_LengthType)8U,  /* FlsSector_22 */
    (Fls_LengthType)8U,  /* FlsSector_23 */
    (Fls_LengthType)8U,  /* FlsSector_24 */
    (Fls_LengthType)8U,  /* FlsSector_25 */
    (Fls_LengthType)8U,  /* FlsSector_26 */
    (Fls_LengthType)8U,  /* FlsSector_27 */
    (Fls_LengthType)8U,  /* FlsSector_28 */
    (Fls_LengthType)8U,  /* FlsSector_29 */
    (Fls_LengthType)8U,  /* FlsSector_30 */
    (Fls_LengthType)8U,  /* FlsSector_31 */
    (Fls_LengthType)8U,  /* FlsSector_32 */
    (Fls_LengthType)8U,  /* FlsSector_33 */
    (Fls_LengthType)8U,  /* FlsSector_34 */
    (Fls_LengthType)8U,  /* FlsSector_35 */
    (Fls_LengthType)8U,  /* FlsSector_36 */
    (Fls_LengthType)8U,  /* FlsSector_37 */
    (Fls_LengthType)8U,  /* FlsSector_38 */
    (Fls_LengthType)8U,  /* FlsSector_39 */
    (Fls_LengthType)8U,  /* FlsSector_40 */
    (Fls_LengthType)8U,  /* FlsSector_41 */
    (Fls_LengthType)8U,  /* FlsSector_42 */
    (Fls_LengthType)8U,  /* FlsSector_43 */
    (Fls_LengthType)8U,  /* FlsSector_44 */
    (Fls_LengthType)8U,  /* FlsSector_45 */
    (Fls_LengthType)8U,  /* FlsSector_46 */
    (Fls_LengthType)8U,  /* FlsSector_47 */
    (Fls_LengthType)8U,  /* FlsSector_48 */
    (Fls_LengthType)8U,  /* FlsSector_49 */
    (Fls_LengthType)8U,  /* FlsSector_50 */
    (Fls_LengthType)8U,  /* FlsSector_51 */
    (Fls_LengthType)8U,  /* FlsSector_52 */
    (Fls_LengthType)8U,  /* FlsSector_53 */
    (Fls_LengthType)8U,  /* FlsSector_54 */
    (Fls_LengthType)8U,  /* FlsSector_55 */
    (Fls_LengthType)8U,  /* FlsSector_56 */
    (Fls_LengthType)8U,  /* FlsSector_57 */
    (Fls_LengthType)8U,  /* FlsSector_58 */
    (Fls_LengthType)8U,  /* FlsSector_59 */
    (Fls_LengthType)8U,  /* FlsSector_60 */
    (Fls_LengthType)8U,  /* FlsSector_61 */
    (Fls_LengthType)8U,  /* FlsSector_62 */
    (Fls_LengthType)8U,  /* FlsSector_63 */
    (Fls_LengthType)8U,  /* FlsSector_64 */
    (Fls_LengthType)8U,  /* FlsSector_65 */
    (Fls_LengthType)8U,  /* FlsSector_66 */
    (Fls_LengthType)8U,  /* FlsSector_67 */
    (Fls_LengthType)8U,  /* FlsSector_68 */
    (Fls_LengthType)8U,  /* FlsSector_69 */
    (Fls_LengthType)8U,  /* FlsSector_70 */
    (Fls_LengthType)8U,  /* FlsSector_71 */
    (Fls_LengthType)8U,  /* FlsSector_72 */
    (Fls_LengthType)8U,  /* FlsSector_73 */
    (Fls_LengthType)8U,  /* FlsSector_74 */
    (Fls_LengthType)8U,  /* FlsSector_75 */
    (Fls_LengthType)8U,  /* FlsSector_76 */
    (Fls_LengthType)8U,  /* FlsSector_77 */
    (Fls_LengthType)8U,  /* FlsSector_78 */
    (Fls_LengthType)8U,  /* FlsSector_79 */
    (Fls_LengthType)8U,  /* FlsSector_80 */
    (Fls_LengthType)8U,  /* FlsSector_81 */
    (Fls_LengthType)8U,  /* FlsSector_82 */
    (Fls_LengthType)8U,  /* FlsSector_83 */
    (Fls_LengthType)8U,  /* FlsSector_84 */
    (Fls_LengthType)8U,  /* FlsSector_85 */
    (Fls_LengthType)8U,  /* FlsSector_86 */
    (Fls_LengthType)8U,  /* FlsSector_87 */
    (Fls_LengthType)8U,  /* FlsSector_88 */
    (Fls_LengthType)8U,  /* FlsSector_89 */
    (Fls_LengthType)8U,  /* FlsSector_90 */
    (Fls_LengthType)8U,  /* FlsSector_91 */
    (Fls_LengthType)8U,  /* FlsSector_92 */
    (Fls_LengthType)8U,  /* FlsSector_93 */
    (Fls_LengthType)8U,  /* FlsSector_94 */
    (Fls_LengthType)8U,  /* FlsSector_95 */
    (Fls_LengthType)8U,  /* FlsSector_96 */
    (Fls_LengthType)8U,  /* FlsSector_97 */
    (Fls_LengthType)8U,  /* FlsSector_98 */
    (Fls_LengthType)8U,  /* FlsSector_99 */
    (Fls_LengthType)8U,  /* FlsSector_100 */
    (Fls_LengthType)8U,  /* FlsSector_101 */
    (Fls_LengthType)8U,  /* FlsSector_102 */
    (Fls_LengthType)8U,  /* FlsSector_103 */
    (Fls_LengthType)8U,  /* FlsSector_104 */
    (Fls_LengthType)8U,  /* FlsSector_105 */
    (Fls_LengthType)8U,  /* FlsSector_106 */
    (Fls_LengthType)8U,  /* FlsSector_107 */
    (Fls_LengthType)8U,  /* FlsSector_108 */
    (Fls_LengthType)8U,  /* FlsSector_109 */
    (Fls_LengthType)8U,  /* FlsSector_110 */
    (Fls_LengthType)8U,  /* FlsSector_111 */
    (Fls_LengthType)8U,  /* FlsSector_112 */
    (Fls_LengthType)8U,  /* FlsSector_113 */
    (Fls_LengthType)8U,  /* FlsSector_114 */
    (Fls_LengthType)8U,  /* FlsSector_115 */
    (Fls_LengthType)8U,  /* FlsSector_116 */
    (Fls_LengthType)8U,  /* FlsSector_117 */
    (Fls_LengthType)8U,  /* FlsSector_118 */
    (Fls_LengthType)8U,  /* FlsSector_119 */
    (Fls_LengthType)8U,  /* FlsSector_120 */
    (Fls_LengthType)8U,  /* FlsSector_121 */
    (Fls_LengthType)8U,  /* FlsSector_122 */
    (Fls_LengthType)8U,  /* FlsSector_123 */
    (Fls_LengthType)8U,  /* FlsSector_124 */
    (Fls_LengthType)8U,  /* FlsSector_125 */
    (Fls_LengthType)8U,  /* FlsSector_126 */
    (Fls_LengthType)8U   /* FlsSector_127 */
};

/* Info structure (reg prot, ecc trigger, etc) for each internal flash sector. */
static const Fls_Flash_InternalSectorInfoType FlsSector_0_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x080000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    160U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_1_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x081000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    161U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_2_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x082000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    162U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_3_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x083000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    163U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_4_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x084000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    164U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_5_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x085000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    165U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_6_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x086000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    166U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_7_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x087000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    167U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_8_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x088000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    168U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_9_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x089000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    169U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_10_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08A000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    170U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_11_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08B000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    171U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_12_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08C000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    172U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_13_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08D000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    173U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_14_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08E000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    174U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_15_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x08F000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    175U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_16_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x090000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    176U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_17_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x091000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    177U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_18_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x092000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    178U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_19_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x093000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    179U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_20_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x094000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    180U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_21_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x095000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    181U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_22_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x096000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    182U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_23_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x097000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    183U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_24_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x098000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    184U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_25_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x099000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    185U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_26_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09A000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    186U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_27_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09B000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    187U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_28_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09C000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    188U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_29_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09D000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    189U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_30_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09E000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    190U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_31_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x09F000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    191U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_32_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    192U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_33_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    193U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_34_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    194U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_35_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    195U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_36_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    196U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_37_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    197U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_38_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    198U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_39_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    199U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_40_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A8000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    200U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_41_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0A9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    201U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_42_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    202U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_43_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    203U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_44_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    204U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_45_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AD000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    205U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_46_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    206U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_47_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0AF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    207U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_48_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    208U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_49_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    209U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_50_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    210U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_51_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    211U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_52_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    212U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_53_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    213U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_54_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    214U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_55_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    215U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_56_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B8000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    216U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_57_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0B9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    217U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_58_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    218U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_59_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    219U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_60_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    220U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_61_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BD000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    221U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_62_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    222U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_63_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0BF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    223U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_64_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    224U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_65_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    225U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_66_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    226U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_67_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    227U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_68_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    228U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_69_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    229U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_70_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    230U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_71_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    231U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_72_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C8000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    232U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_73_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0C9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    233U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_74_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    234U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_75_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    235U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_76_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    236U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_77_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CD000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    237U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_78_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    238U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_79_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0CF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    239U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_80_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    240U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_81_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    241U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_82_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    242U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_83_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    243U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_84_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    244U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_85_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    245U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_86_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    246U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_87_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    247U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_88_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x038000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_0), /* code block 0 */
    (boolean)TRUE,  /* bEccTriggersExc */
    88U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_89_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0D9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    249U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_90_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    250U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_91_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    251U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_92_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    252U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_93_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DD000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    253U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_94_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    254U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_95_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0DF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    255U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_96_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    256U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_97_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    257U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_98_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    258U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_99_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    259U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_100_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    260U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_101_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    261U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_102_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    262U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_103_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    263U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_104_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E8000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    264U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_105_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0E9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    265U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_106_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0EA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    266U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_107_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0EB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    267U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_108_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0EC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    268U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_109_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0ED000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    269U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_110_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0EE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    270U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_111_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0EF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    271U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_112_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F0000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    272U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_113_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F1000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    273U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_114_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F2000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    274U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_115_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F3000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    275U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_116_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F4000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    276U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_117_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F5000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    277U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_118_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F6000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    278U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_119_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F7000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    279U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_120_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F8000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    280U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_121_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0F9000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    281U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_122_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FA000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    282U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_123_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FB000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    283U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_124_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FC000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    284U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_125_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FD000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    285U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_126_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FE000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    286U  /* Sector location to calculate cfgCRC */
};

static const Fls_Flash_InternalSectorInfoType FlsSector_127_FlsConfigSet_VS_0_sInternalSectorInfo =
{
    (FLS_PROGRAM_FLASH_BASE_ADDR + 0x0FF000UL),  /* pSectorStartAddressPtr */
    (Fls_BlockNumberOfSectorType)(FLS_CODE_BLOCK_1), /* code block 1 */
    (boolean)TRUE,  /* bEccTriggersExc */
    287U  /* Sector location to calculate cfgCRC */
};


/* FLASH physical sectorization description */
static const Fls_Flash_InternalSectorInfoType * const FlsConfigSet_VS_0_aSectorList[128U] =
{
    &FlsSector_0_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S128 */
    &FlsSector_1_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S129 */
    &FlsSector_2_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S130 */
    &FlsSector_3_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S131 */
    &FlsSector_4_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S132 */
    &FlsSector_5_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S133 */
    &FlsSector_6_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S134 */
    &FlsSector_7_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S135 */
    &FlsSector_8_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S136 */
    &FlsSector_9_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S137 */
    &FlsSector_10_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S138 */
    &FlsSector_11_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S139 */
    &FlsSector_12_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S140 */
    &FlsSector_13_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S141 */
    &FlsSector_14_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S142 */
    &FlsSector_15_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S143 */
    &FlsSector_16_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S144 */
    &FlsSector_17_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S145 */
    &FlsSector_18_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S146 */
    &FlsSector_19_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S147 */
    &FlsSector_20_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S148 */
    &FlsSector_21_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S149 */
    &FlsSector_22_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S150 */
    &FlsSector_23_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S151 */
    &FlsSector_24_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S152 */
    &FlsSector_25_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S153 */
    &FlsSector_26_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S154 */
    &FlsSector_27_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S155 */
    &FlsSector_28_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S156 */
    &FlsSector_29_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S157 */
    &FlsSector_30_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S158 */
    &FlsSector_31_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S159 */
    &FlsSector_32_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S160 */
    &FlsSector_33_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S161 */
    &FlsSector_34_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S162 */
    &FlsSector_35_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S163 */
    &FlsSector_36_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S164 */
    &FlsSector_37_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S165 */
    &FlsSector_38_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S166 */
    &FlsSector_39_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S167 */
    &FlsSector_40_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S168 */
    &FlsSector_41_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S169 */
    &FlsSector_42_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S170 */
    &FlsSector_43_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S171 */
    &FlsSector_44_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S172 */
    &FlsSector_45_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S173 */
    &FlsSector_46_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S174 */
    &FlsSector_47_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S175 */
    &FlsSector_48_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S176 */
    &FlsSector_49_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S177 */
    &FlsSector_50_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S178 */
    &FlsSector_51_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S179 */
    &FlsSector_52_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S180 */
    &FlsSector_53_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S181 */
    &FlsSector_54_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S182 */
    &FlsSector_55_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S183 */
    &FlsSector_56_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S184 */
    &FlsSector_57_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S185 */
    &FlsSector_58_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S186 */
    &FlsSector_59_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S187 */
    &FlsSector_60_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S188 */
    &FlsSector_61_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S189 */
    &FlsSector_62_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S190 */
    &FlsSector_63_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S191 */
    &FlsSector_64_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S192 */
    &FlsSector_65_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S193 */
    &FlsSector_66_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S194 */
    &FlsSector_67_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S195 */
    &FlsSector_68_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S196 */
    &FlsSector_69_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S197 */
    &FlsSector_70_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S198 */
    &FlsSector_71_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S199 */
    &FlsSector_72_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S200 */
    &FlsSector_73_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S201 */
    &FlsSector_74_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S202 */
    &FlsSector_75_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S203 */
    &FlsSector_76_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S204 */
    &FlsSector_77_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S205 */
    &FlsSector_78_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S206 */
    &FlsSector_79_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S207 */
    &FlsSector_80_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S208 */
    &FlsSector_81_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S209 */
    &FlsSector_82_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S210 */
    &FlsSector_83_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S211 */
    &FlsSector_84_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S212 */
    &FlsSector_85_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S213 */
    &FlsSector_86_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S214 */
    &FlsSector_87_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S215 */
    &FlsSector_88_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_0_S056 */
    &FlsSector_89_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S217 */
    &FlsSector_90_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S218 */
    &FlsSector_91_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S219 */
    &FlsSector_92_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S220 */
    &FlsSector_93_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S221 */
    &FlsSector_94_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S222 */
    &FlsSector_95_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S223 */
    &FlsSector_96_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S224 */
    &FlsSector_97_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S225 */
    &FlsSector_98_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S226 */
    &FlsSector_99_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S227 */
    &FlsSector_100_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S228 */
    &FlsSector_101_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S229 */
    &FlsSector_102_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S230 */
    &FlsSector_103_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S231 */
    &FlsSector_104_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S232 */
    &FlsSector_105_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S233 */
    &FlsSector_106_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S234 */
    &FlsSector_107_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S235 */
    &FlsSector_108_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S236 */
    &FlsSector_109_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S237 */
    &FlsSector_110_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S238 */
    &FlsSector_111_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S239 */
    &FlsSector_112_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S240 */
    &FlsSector_113_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S241 */
    &FlsSector_114_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S242 */
    &FlsSector_115_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S243 */
    &FlsSector_116_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S244 */
    &FlsSector_117_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S245 */
    &FlsSector_118_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S246 */
    &FlsSector_119_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S247 */
    &FlsSector_120_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S248 */
    &FlsSector_121_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S249 */
    &FlsSector_122_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S250 */
    &FlsSector_123_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S251 */
    &FlsSector_124_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S252 */
    &FlsSector_125_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S253 */
    &FlsSector_126_FlsConfigSet_VS_0_sInternalSectorInfo,  /* FLS_CODE_ARRAY_0_BLOCK_1_S254 */
    &FlsSector_127_FlsConfigSet_VS_0_sInternalSectorInfo   /* FLS_CODE_ARRAY_0_BLOCK_1_S255 */
};

/* paHwCh */
static const Fls_HwChType FlsConfigSet_VS_0_paHwCh[128U] =
{
    FLS_CH_INTERN,  /* FlsSector_0 */
    FLS_CH_INTERN,  /* FlsSector_1 */
    FLS_CH_INTERN,  /* FlsSector_2 */
    FLS_CH_INTERN,  /* FlsSector_3 */
    FLS_CH_INTERN,  /* FlsSector_4 */
    FLS_CH_INTERN,  /* FlsSector_5 */
    FLS_CH_INTERN,  /* FlsSector_6 */
    FLS_CH_INTERN,  /* FlsSector_7 */
    FLS_CH_INTERN,  /* FlsSector_8 */
    FLS_CH_INTERN,  /* FlsSector_9 */
    FLS_CH_INTERN,  /* FlsSector_10 */
    FLS_CH_INTERN,  /* FlsSector_11 */
    FLS_CH_INTERN,  /* FlsSector_12 */
    FLS_CH_INTERN,  /* FlsSector_13 */
    FLS_CH_INTERN,  /* FlsSector_14 */
    FLS_CH_INTERN,  /* FlsSector_15 */
    FLS_CH_INTERN,  /* FlsSector_16 */
    FLS_CH_INTERN,  /* FlsSector_17 */
    FLS_CH_INTERN,  /* FlsSector_18 */
    FLS_CH_INTERN,  /* FlsSector_19 */
    FLS_CH_INTERN,  /* FlsSector_20 */
    FLS_CH_INTERN,  /* FlsSector_21 */
    FLS_CH_INTERN,  /* FlsSector_22 */
    FLS_CH_INTERN,  /* FlsSector_23 */
    FLS_CH_INTERN,  /* FlsSector_24 */
    FLS_CH_INTERN,  /* FlsSector_25 */
    FLS_CH_INTERN,  /* FlsSector_26 */
    FLS_CH_INTERN,  /* FlsSector_27 */
    FLS_CH_INTERN,  /* FlsSector_28 */
    FLS_CH_INTERN,  /* FlsSector_29 */
    FLS_CH_INTERN,  /* FlsSector_30 */
    FLS_CH_INTERN,  /* FlsSector_31 */
    FLS_CH_INTERN,  /* FlsSector_32 */
    FLS_CH_INTERN,  /* FlsSector_33 */
    FLS_CH_INTERN,  /* FlsSector_34 */
    FLS_CH_INTERN,  /* FlsSector_35 */
    FLS_CH_INTERN,  /* FlsSector_36 */
    FLS_CH_INTERN,  /* FlsSector_37 */
    FLS_CH_INTERN,  /* FlsSector_38 */
    FLS_CH_INTERN,  /* FlsSector_39 */
    FLS_CH_INTERN,  /* FlsSector_40 */
    FLS_CH_INTERN,  /* FlsSector_41 */
    FLS_CH_INTERN,  /* FlsSector_42 */
    FLS_CH_INTERN,  /* FlsSector_43 */
    FLS_CH_INTERN,  /* FlsSector_44 */
    FLS_CH_INTERN,  /* FlsSector_45 */
    FLS_CH_INTERN,  /* FlsSector_46 */
    FLS_CH_INTERN,  /* FlsSector_47 */
    FLS_CH_INTERN,  /* FlsSector_48 */
    FLS_CH_INTERN,  /* FlsSector_49 */
    FLS_CH_INTERN,  /* FlsSector_50 */
    FLS_CH_INTERN,  /* FlsSector_51 */
    FLS_CH_INTERN,  /* FlsSector_52 */
    FLS_CH_INTERN,  /* FlsSector_53 */
    FLS_CH_INTERN,  /* FlsSector_54 */
    FLS_CH_INTERN,  /* FlsSector_55 */
    FLS_CH_INTERN,  /* FlsSector_56 */
    FLS_CH_INTERN,  /* FlsSector_57 */
    FLS_CH_INTERN,  /* FlsSector_58 */
    FLS_CH_INTERN,  /* FlsSector_59 */
    FLS_CH_INTERN,  /* FlsSector_60 */
    FLS_CH_INTERN,  /* FlsSector_61 */
    FLS_CH_INTERN,  /* FlsSector_62 */
    FLS_CH_INTERN,  /* FlsSector_63 */
    FLS_CH_INTERN,  /* FlsSector_64 */
    FLS_CH_INTERN,  /* FlsSector_65 */
    FLS_CH_INTERN,  /* FlsSector_66 */
    FLS_CH_INTERN,  /* FlsSector_67 */
    FLS_CH_INTERN,  /* FlsSector_68 */
    FLS_CH_INTERN,  /* FlsSector_69 */
    FLS_CH_INTERN,  /* FlsSector_70 */
    FLS_CH_INTERN,  /* FlsSector_71 */
    FLS_CH_INTERN,  /* FlsSector_72 */
    FLS_CH_INTERN,  /* FlsSector_73 */
    FLS_CH_INTERN,  /* FlsSector_74 */
    FLS_CH_INTERN,  /* FlsSector_75 */
    FLS_CH_INTERN,  /* FlsSector_76 */
    FLS_CH_INTERN,  /* FlsSector_77 */
    FLS_CH_INTERN,  /* FlsSector_78 */
    FLS_CH_INTERN,  /* FlsSector_79 */
    FLS_CH_INTERN,  /* FlsSector_80 */
    FLS_CH_INTERN,  /* FlsSector_81 */
    FLS_CH_INTERN,  /* FlsSector_82 */
    FLS_CH_INTERN,  /* FlsSector_83 */
    FLS_CH_INTERN,  /* FlsSector_84 */
    FLS_CH_INTERN,  /* FlsSector_85 */
    FLS_CH_INTERN,  /* FlsSector_86 */
    FLS_CH_INTERN,  /* FlsSector_87 */
    FLS_CH_INTERN,  /* FlsSector_88 */
    FLS_CH_INTERN,  /* FlsSector_89 */
    FLS_CH_INTERN,  /* FlsSector_90 */
    FLS_CH_INTERN,  /* FlsSector_91 */
    FLS_CH_INTERN,  /* FlsSector_92 */
    FLS_CH_INTERN,  /* FlsSector_93 */
    FLS_CH_INTERN,  /* FlsSector_94 */
    FLS_CH_INTERN,  /* FlsSector_95 */
    FLS_CH_INTERN,  /* FlsSector_96 */
    FLS_CH_INTERN,  /* FlsSector_97 */
    FLS_CH_INTERN,  /* FlsSector_98 */
    FLS_CH_INTERN,  /* FlsSector_99 */
    FLS_CH_INTERN,  /* FlsSector_100 */
    FLS_CH_INTERN,  /* FlsSector_101 */
    FLS_CH_INTERN,  /* FlsSector_102 */
    FLS_CH_INTERN,  /* FlsSector_103 */
    FLS_CH_INTERN,  /* FlsSector_104 */
    FLS_CH_INTERN,  /* FlsSector_105 */
    FLS_CH_INTERN,  /* FlsSector_106 */
    FLS_CH_INTERN,  /* FlsSector_107 */
    FLS_CH_INTERN,  /* FlsSector_108 */
    FLS_CH_INTERN,  /* FlsSector_109 */
    FLS_CH_INTERN,  /* FlsSector_110 */
    FLS_CH_INTERN,  /* FlsSector_111 */
    FLS_CH_INTERN,  /* FlsSector_112 */
    FLS_CH_INTERN,  /* FlsSector_113 */
    FLS_CH_INTERN,  /* FlsSector_114 */
    FLS_CH_INTERN,  /* FlsSector_115 */
    FLS_CH_INTERN,  /* FlsSector_116 */
    FLS_CH_INTERN,  /* FlsSector_117 */
    FLS_CH_INTERN,  /* FlsSector_118 */
    FLS_CH_INTERN,  /* FlsSector_119 */
    FLS_CH_INTERN,  /* FlsSector_120 */
    FLS_CH_INTERN,  /* FlsSector_121 */
    FLS_CH_INTERN,  /* FlsSector_122 */
    FLS_CH_INTERN,  /* FlsSector_123 */
    FLS_CH_INTERN,  /* FlsSector_124 */
    FLS_CH_INTERN,  /* FlsSector_125 */
    FLS_CH_INTERN,  /* FlsSector_126 */
    FLS_CH_INTERN   /* FlsSector_127 */
};

/* paSectorHwAddress */
static const Fls_AddressType FlsConfigSet_VS_0_paSectorHwAddress[128U] =
{
    (Fls_AddressType)0U,  /* FlsSector_0 */
    (Fls_AddressType)0U,  /* FlsSector_1 */
    (Fls_AddressType)0U,  /* FlsSector_2 */
    (Fls_AddressType)0U,  /* FlsSector_3 */
    (Fls_AddressType)0U,  /* FlsSector_4 */
    (Fls_AddressType)0U,  /* FlsSector_5 */
    (Fls_AddressType)0U,  /* FlsSector_6 */
    (Fls_AddressType)0U,  /* FlsSector_7 */
    (Fls_AddressType)0U,  /* FlsSector_8 */
    (Fls_AddressType)0U,  /* FlsSector_9 */
    (Fls_AddressType)0U,  /* FlsSector_10 */
    (Fls_AddressType)0U,  /* FlsSector_11 */
    (Fls_AddressType)0U,  /* FlsSector_12 */
    (Fls_AddressType)0U,  /* FlsSector_13 */
    (Fls_AddressType)0U,  /* FlsSector_14 */
    (Fls_AddressType)0U,  /* FlsSector_15 */
    (Fls_AddressType)0U,  /* FlsSector_16 */
    (Fls_AddressType)0U,  /* FlsSector_17 */
    (Fls_AddressType)0U,  /* FlsSector_18 */
    (Fls_AddressType)0U,  /* FlsSector_19 */
    (Fls_AddressType)0U,  /* FlsSector_20 */
    (Fls_AddressType)0U,  /* FlsSector_21 */
    (Fls_AddressType)0U,  /* FlsSector_22 */
    (Fls_AddressType)0U,  /* FlsSector_23 */
    (Fls_AddressType)0U,  /* FlsSector_24 */
    (Fls_AddressType)0U,  /* FlsSector_25 */
    (Fls_AddressType)0U,  /* FlsSector_26 */
    (Fls_AddressType)0U,  /* FlsSector_27 */
    (Fls_AddressType)0U,  /* FlsSector_28 */
    (Fls_AddressType)0U,  /* FlsSector_29 */
    (Fls_AddressType)0U,  /* FlsSector_30 */
    (Fls_AddressType)0U,  /* FlsSector_31 */
    (Fls_AddressType)0U,  /* FlsSector_32 */
    (Fls_AddressType)0U,  /* FlsSector_33 */
    (Fls_AddressType)0U,  /* FlsSector_34 */
    (Fls_AddressType)0U,  /* FlsSector_35 */
    (Fls_AddressType)0U,  /* FlsSector_36 */
    (Fls_AddressType)0U,  /* FlsSector_37 */
    (Fls_AddressType)0U,  /* FlsSector_38 */
    (Fls_AddressType)0U,  /* FlsSector_39 */
    (Fls_AddressType)0U,  /* FlsSector_40 */
    (Fls_AddressType)0U,  /* FlsSector_41 */
    (Fls_AddressType)0U,  /* FlsSector_42 */
    (Fls_AddressType)0U,  /* FlsSector_43 */
    (Fls_AddressType)0U,  /* FlsSector_44 */
    (Fls_AddressType)0U,  /* FlsSector_45 */
    (Fls_AddressType)0U,  /* FlsSector_46 */
    (Fls_AddressType)0U,  /* FlsSector_47 */
    (Fls_AddressType)0U,  /* FlsSector_48 */
    (Fls_AddressType)0U,  /* FlsSector_49 */
    (Fls_AddressType)0U,  /* FlsSector_50 */
    (Fls_AddressType)0U,  /* FlsSector_51 */
    (Fls_AddressType)0U,  /* FlsSector_52 */
    (Fls_AddressType)0U,  /* FlsSector_53 */
    (Fls_AddressType)0U,  /* FlsSector_54 */
    (Fls_AddressType)0U,  /* FlsSector_55 */
    (Fls_AddressType)0U,  /* FlsSector_56 */
    (Fls_AddressType)0U,  /* FlsSector_57 */
    (Fls_AddressType)0U,  /* FlsSector_58 */
    (Fls_AddressType)0U,  /* FlsSector_59 */
    (Fls_AddressType)0U,  /* FlsSector_60 */
    (Fls_AddressType)0U,  /* FlsSector_61 */
    (Fls_AddressType)0U,  /* FlsSector_62 */
    (Fls_AddressType)0U,  /* FlsSector_63 */
    (Fls_AddressType)0U,  /* FlsSector_64 */
    (Fls_AddressType)0U,  /* FlsSector_65 */
    (Fls_AddressType)0U,  /* FlsSector_66 */
    (Fls_AddressType)0U,  /* FlsSector_67 */
    (Fls_AddressType)0U,  /* FlsSector_68 */
    (Fls_AddressType)0U,  /* FlsSector_69 */
    (Fls_AddressType)0U,  /* FlsSector_70 */
    (Fls_AddressType)0U,  /* FlsSector_71 */
    (Fls_AddressType)0U,  /* FlsSector_72 */
    (Fls_AddressType)0U,  /* FlsSector_73 */
    (Fls_AddressType)0U,  /* FlsSector_74 */
    (Fls_AddressType)0U,  /* FlsSector_75 */
    (Fls_AddressType)0U,  /* FlsSector_76 */
    (Fls_AddressType)0U,  /* FlsSector_77 */
    (Fls_AddressType)0U,  /* FlsSector_78 */
    (Fls_AddressType)0U,  /* FlsSector_79 */
    (Fls_AddressType)0U,  /* FlsSector_80 */
    (Fls_AddressType)0U,  /* FlsSector_81 */
    (Fls_AddressType)0U,  /* FlsSector_82 */
    (Fls_AddressType)0U,  /* FlsSector_83 */
    (Fls_AddressType)0U,  /* FlsSector_84 */
    (Fls_AddressType)0U,  /* FlsSector_85 */
    (Fls_AddressType)0U,  /* FlsSector_86 */
    (Fls_AddressType)0U,  /* FlsSector_87 */
    (Fls_AddressType)0U,  /* FlsSector_88 */
    (Fls_AddressType)0U,  /* FlsSector_89 */
    (Fls_AddressType)0U,  /* FlsSector_90 */
    (Fls_AddressType)0U,  /* FlsSector_91 */
    (Fls_AddressType)0U,  /* FlsSector_92 */
    (Fls_AddressType)0U,  /* FlsSector_93 */
    (Fls_AddressType)0U,  /* FlsSector_94 */
    (Fls_AddressType)0U,  /* FlsSector_95 */
    (Fls_AddressType)0U,  /* FlsSector_96 */
    (Fls_AddressType)0U,  /* FlsSector_97 */
    (Fls_AddressType)0U,  /* FlsSector_98 */
    (Fls_AddressType)0U,  /* FlsSector_99 */
    (Fls_AddressType)0U,  /* FlsSector_100 */
    (Fls_AddressType)0U,  /* FlsSector_101 */
    (Fls_AddressType)0U,  /* FlsSector_102 */
    (Fls_AddressType)0U,  /* FlsSector_103 */
    (Fls_AddressType)0U,  /* FlsSector_104 */
    (Fls_AddressType)0U,  /* FlsSector_105 */
    (Fls_AddressType)0U,  /* FlsSector_106 */
    (Fls_AddressType)0U,  /* FlsSector_107 */
    (Fls_AddressType)0U,  /* FlsSector_108 */
    (Fls_AddressType)0U,  /* FlsSector_109 */
    (Fls_AddressType)0U,  /* FlsSector_110 */
    (Fls_AddressType)0U,  /* FlsSector_111 */
    (Fls_AddressType)0U,  /* FlsSector_112 */
    (Fls_AddressType)0U,  /* FlsSector_113 */
    (Fls_AddressType)0U,  /* FlsSector_114 */
    (Fls_AddressType)0U,  /* FlsSector_115 */
    (Fls_AddressType)0U,  /* FlsSector_116 */
    (Fls_AddressType)0U,  /* FlsSector_117 */
    (Fls_AddressType)0U,  /* FlsSector_118 */
    (Fls_AddressType)0U,  /* FlsSector_119 */
    (Fls_AddressType)0U,  /* FlsSector_120 */
    (Fls_AddressType)0U,  /* FlsSector_121 */
    (Fls_AddressType)0U,  /* FlsSector_122 */
    (Fls_AddressType)0U,  /* FlsSector_123 */
    (Fls_AddressType)0U,  /* FlsSector_124 */
    (Fls_AddressType)0U,  /* FlsSector_125 */
    (Fls_AddressType)0U,  /* FlsSector_126 */
    (Fls_AddressType)0U   /* FlsSector_127 */
};



/**
* @brief        Structure used to set function pointers notification, working mode
*/
/* Fls module initialization data (FlsConfigSet)*/
const Fls_ConfigType Fls_Config_VS_0 =
{
    (Fls_AcErasePtrType)&_ERASE_FUNC_ADDRESS_,                        /* FlsAcErase */
    (Fls_AcWritePtrType)&_WRITE_FUNC_ADDRESS_,                        /* FlsAcWrite */
    NULL_PTR,                                                         /* FlsACCallback */
    NULL_PTR,                                                         /* FlsJobEndNotification */
    NULL_PTR,                                                         /* FlsJobErrorNotification */
    NULL_PTR,                                                         /* FlsReadFunctionCallout */
    MEMIF_MODE_SLOW,                                                  /* FlsDefaultMode */
    1048576U,                                                         /* FlsMaxReadFastMode */
    1024U,                                                            /* FlsMaxReadNormalMode */
    256U,                                                             /* FlsMaxWriteFastMode */
    8U,                                                               /* FlsMaxWriteNormalMode */
    128U,                                                             /* FlsSectorCount */
    &FlsConfigSet_VS_0_aFlsSectorEndAddr,                             /* (*paSectorEndAddr)[] */
    &FlsConfigSet_VS_0_aFlsSectorSize,                                /* (*paSectorSize)[] */
    &FlsConfigSet_VS_0_aSectorList,                                   /* (*pSectorList)[] */
    &FlsConfigSet_VS_0_aFlsSectorFlags,                               /* (*paSectorFlags)[] */
    &FlsConfigSet_VS_0_aFlsSectorPageSize,                            /* (*paSectorPageSize)[] */
    &FlsConfigSet_VS_0_paHwCh,                                        /* (*paHwCh)[] */
    &FlsConfigSet_VS_0_paSectorHwAddress,                             /* (*paSectorHwAddress)[] */
    NULL_PTR,                                                         /* FlsQspiConfig */
    &FlsConfigSet_VS_0_InitCfg,                                       /* FlsInternalConfig */
    27560U                                                            /* configCrc */
};


#define FLS_STOP_SEC_CONFIG_DATA_UNSPECIFIED
#include "Fls_MemMap.h"


#ifdef __cplusplus
}
#endif

/** @}*/

